@@ -80,7 +80,7 @@ impl<'c, 'f> FsVisitor for Visitor<'c, 'f> {
         if self.filter.matches(info.name()) {
             let new_path = info.path();
             let crc = calculate_crc(new_path.as_bytes());
-            println!("dir-file {}", new_path);
+            log::debug!("dir-file {}", new_path);
             match self.effect {
                 ArgEffect::Include => {
                     self.crc_set.insert(crc);
@@ -113,7 +113,7 @@ impl Config {
                 match &arg.kind {
                     ArgKind::File => {
                         let crc = calculate_crc(path.as_bytes());
-                        println!("file {}", path);
+                        log::debug!("file {}", path);
                         match arg.effect {
                             ArgEffect::Include => {
                                 crc_set.insert(crc);
